import { HttpClient, MaybeContext, BuildRESTFunction } from '@wix/sdk-types';
import { CheckDomainAvailabilityResponse } from './index.typings.mjs';
export { CheckDomainAvailabilityRequest, DomainAvailability, PremiumType } from './index.typings.mjs';

declare function checkDomainAvailability$1(httpClient: HttpClient): CheckDomainAvailabilitySignature;
interface CheckDomainAvailabilitySignature {
    /**
     * Checks whether the given domain is available for purchase.
     *
     *
     * You can purchase the specified domain in case the returned
     * `availability.available` boolean is `true`. The domain is already taken
     * when `false` is returned.
     *
     * The `domain` field must include the TLD. For example, `my-new-domain.com`.
     *
     * > __Important:__ This call requires an account level API key and cannot be authenticated with the standard authorization header.
     * @param - Domain name. Must include the TLD. For example, `my-new-domain.com`. Only
     * alphanumeric characters, hyphens, and dots are supported.
     *
     * Min: 3 characters
     * Max: 63 characters
     */
    (domain: string): Promise<CheckDomainAvailabilityResponse>;
}

declare const checkDomainAvailability: MaybeContext<BuildRESTFunction<typeof checkDomainAvailability$1> & typeof checkDomainAvailability$1>;

export { CheckDomainAvailabilityResponse, checkDomainAvailability };
