// src/premium-domains-v2-availability-domain-availability.universal.ts
import { transformError as sdkTransformError } from "@wix/sdk-runtime/transform-error";
import {
  renameKeysFromSDKRequestToRESTRequest,
  renameKeysFromRESTResponseToSDKResponse
} from "@wix/sdk-runtime/rename-all-nested-keys";

// src/premium-domains-v2-availability-domain-availability.http.ts
import { toURLSearchParams } from "@wix/sdk-runtime/rest-modules";
import { resolveUrl } from "@wix/sdk-runtime/rest-modules";
function resolveComWixpressPremiumDomainSearchAvailabilityV2DomainAvailabilityServiceUrl(opts) {
  const domainToMappings = {
    "www._base_domain_": [
      {
        srcPath: "/domain-search/v2",
        destPath: "/v2"
      },
      {
        srcPath: "/v2/suggest-domains",
        destPath: "/v2/suggest-domains"
      }
    ],
    "manage._base_domain_": [
      {
        srcPath: "/v2/check-domain-availability",
        destPath: "/v2/check-domain-availability"
      },
      {
        srcPath: "/v2/suggest-domains",
        destPath: "/v2/suggest-domains"
      }
    ],
    "premium._base_domain_": [
      {
        srcPath: "/v2/check-domain-availability",
        destPath: "/v2/check-domain-availability"
      },
      {
        srcPath: "/v2/suggest-domains",
        destPath: "/v2/suggest-domains"
      }
    ],
    "www.wixapis.com": [
      {
        srcPath: "/domain-search/v2",
        destPath: "/v2"
      },
      {
        srcPath: "/premium/domains/v2/check-domain-availability",
        destPath: "/v2/check-domain-availability"
      },
      {
        srcPath: "/premium/domains/v2/suggest-domains",
        destPath: "/v2/suggest-domains"
      }
    ],
    "editor._base_domain_": [
      {
        srcPath: "/v2/check-domain-availability",
        destPath: "/v2/check-domain-availability"
      },
      {
        srcPath: "/v2/suggest-domains",
        destPath: "/v2/suggest-domains"
      }
    ],
    "blocks._base_domain_": [
      {
        srcPath: "/v2/check-domain-availability",
        destPath: "/v2/check-domain-availability"
      },
      {
        srcPath: "/v2/suggest-domains",
        destPath: "/v2/suggest-domains"
      }
    ],
    "create.editorx": [
      {
        srcPath: "/v2/check-domain-availability",
        destPath: "/v2/check-domain-availability"
      },
      {
        srcPath: "/v2/suggest-domains",
        destPath: "/v2/suggest-domains"
      }
    ],
    "*.dev.wix-code.com": [
      {
        srcPath: "/premium/domains/v2/check-domain-availability",
        destPath: "/v2/check-domain-availability"
      },
      {
        srcPath: "/premium/domains/v2/suggest-domains",
        destPath: "/v2/suggest-domains"
      }
    ],
    _: [
      {
        srcPath: "/premium/domains/v2/check-domain-availability",
        destPath: "/v2/check-domain-availability"
      },
      {
        srcPath: "/premium/domains/v2/suggest-domains",
        destPath: "/v2/suggest-domains"
      }
    ]
  };
  return resolveUrl(Object.assign(opts, { domainToMappings }));
}
var PACKAGE_NAME = "@wix/auto_sdk_domains_domain-availability";
function checkDomainAvailability(payload) {
  function __checkDomainAvailability({ host }) {
    const metadata = {
      entityFqdn: "wix.premium.domains.v2.availability",
      method: "GET",
      methodFqn: "com.wixpress.premium.domain.search.availability.v2.DomainAvailabilityService.CheckDomainAvailability",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressPremiumDomainSearchAvailabilityV2DomainAvailabilityServiceUrl(
        { protoPath: "/v2/check-domain-availability", data: payload, host }
      ),
      params: toURLSearchParams(payload)
    };
    return metadata;
  }
  return __checkDomainAvailability;
}

// src/premium-domains-v2-availability-domain-availability.universal.ts
var PremiumType = /* @__PURE__ */ ((PremiumType2) => {
  PremiumType2["UNKNOWN_PREMIUM_TYPE"] = "UNKNOWN_PREMIUM_TYPE";
  PremiumType2["FIRST_YEAR_ONLY"] = "FIRST_YEAR_ONLY";
  PremiumType2["FIRST_YEAR_AND_RENEWAL"] = "FIRST_YEAR_AND_RENEWAL";
  return PremiumType2;
})(PremiumType || {});
async function checkDomainAvailability2(domain) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest({ domain });
  const reqOpts = checkDomainAvailability(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { domain: "$[0]" },
        singleArgumentUnchanged: false
      },
      ["domain"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}

// src/premium-domains-v2-availability-domain-availability.public.ts
function checkDomainAvailability3(httpClient) {
  return (domain) => checkDomainAvailability2(
    domain,
    // @ts-ignore
    { httpClient }
  );
}

// src/premium-domains-v2-availability-domain-availability.context.ts
import { createRESTModule } from "@wix/sdk-runtime/rest-modules";
var checkDomainAvailability4 = /* @__PURE__ */ createRESTModule(checkDomainAvailability3);
export {
  PremiumType,
  checkDomainAvailability4 as checkDomainAvailability
};
//# sourceMappingURL=index.mjs.map